==> openocd_0.4.0.orig.tar.gz: openocd-0.4.0.orig/src/hello.h <==
/***************************************************************************
 *   Copyright (C) 2009 Zachary T Welch <zw@superlucidity.net>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef OPENOCD_HELLO_H
#define OPENOCD_HELLO_H

struct command_context;
struct command_registration;

/// Register the hello commands in the specified command_context
int hello_register_commands(struct command_context *cmd_ctx);

/**
 * Export the registration for the hello command group, so it can be
 * embedded in example drivers.
 */
extern const struct command_registration hello_command_handlers[];

#endif // OPENOCD_HELLO_H

==> openocd_0.7.0.orig.tar.gz: openocd-0.7.0/src/hello.h <==
/***************************************************************************
 *   Copyright (C) 2009 Zachary T Welch <zw@superlucidity.net>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef OPENOCD_HELLO_H
#define OPENOCD_HELLO_H

struct command_registration;

/**
 * Export the registration for the hello command group, so it can be
 * embedded in example drivers.
 */
extern const struct command_registration hello_command_handlers[];

#endif	/* OPENOCD_HELLO_H */
